pub struct AssetInfo {
pub source: AssetSource,
pub index_loaded: bool,
pub index_entries: Option<usize>,
pub user_cache_present: bool,
pub cache_path: String,
pub bundle_present: bool,
}Expand description
Asset-cache state behind device renders.
Fields
source: AssetSourceindex_loaded: boolindex_entries: Option<usize>Number of device models in the loaded index, when known.
user_cache_present: boolcache_path: StringCache directory with the home prefix redacted to ~.
bundle_present: boolTrait Implementations
Sourceimpl<'de> Deserialize<'de> for AssetInfo
impl<'de> Deserialize<'de> for AssetInfo
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for AssetInfo
impl StructuralPartialEq for AssetInfo