pub struct InstanceGuard { /* private fields */ }Expand description
Held by main for the duration of the run; dropped on exit (the OS
releases the underlying file lock at the same time). The _handle field
is intentionally unused — the value is alive only for its Drop side
effect of closing the fd.